﻿using System;
using System.Collections.Generic;
using System.IO.Ports;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace DeviceClasses
{
    public class ZioLinkUartInterface : SerialPortInterface
    {
        public ZioLinkUartInterface(string devicePath) : base(devicePath)
        {

        }

        public override void Open()
        {
            base.Open();
            port.DiscardInBuffer();
            port.DiscardOutBuffer();
        }

        private byte[] ifaceCmd_Write = new byte[] { 0x02, 0xF1, 0x00, 0x00 };
        private byte[] header = new byte[8];

        public override int Read(byte[] buffer, int count)
        {
            int n = base.Read(header, 8);
            if (n != 8) throw new CommunicationException("Only " + n + " instead of 8 bytes received.");
            int ret = System.BitConverter.ToInt32(header, 0);
            if (ret != 0) throw new CommunicationException("Interface error code 0x" + ret.ToString("X4") + " received.");
            int len = System.BitConverter.ToInt32(header, 4);
            if (len > count) len = count;
            n = base.Read(buffer, len);
            return n;
        }

        public override void Write(byte[] buffer, int count)
        {
            checkLastError();
            port.Write(ifaceCmd_Write, 0, 4);
            port.Write(System.BitConverter.GetBytes(count), 0, 4);
            port.Write(buffer, 0, count);
        }

    }
}
